@@ -477,7 +477,7 @@ class Manifest:
                 path_to_hyperthought_id[path] = utils.generate_id()
 
         def get_hyperthought_id_path(path):
-            hyperthought_id_path = ","
+            hyperthought_id_path = self.hyperthought_root_id_path
 
             for ancestor_path in get_ancestor_paths(path):
                 ancestor_hyperthought_id = (
